View source: R/initialInputCheck.R
Creates an error message if there are any nas given in x lower or upper
1 | checkForNAs(x, lower, upper)
|
x |
is an optional start point (or set of start points), specified as a matrix. One row for each point, and one column for each optimized parameter. |
lower |
is a vector that defines the lower boundary of search space. This determines also the dimensionality of the problem. |
upper |
is a vector that defines the upper boundary of search space. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.