Description Usage Arguments Value Examples
For minimization, this function uses the "DEoptim" method from the
codeDEoptim package. It is basically a wrapper, to enable DEoptim for usage
in SPOT.
1 |
x |
optional start point, not used in DEoptim |
fun |
objective function, which receives a matrix x and returns observations y |
lower |
boundary of the search space |
upper |
boundary of the search space |
control |
list of control parameters
|
... |
passed to |
list, with elements
xarchive of the best member at each iteration
yarchive of the best value of fn at each iteration
xbestbest solution
ybestbest observation
countnumber of evaluations of fun
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.